==> vdkxdb_0.0.4.orig.tar.gz: vdkxdb-0.0.4/testxdb/testxdb_gui.h <==
/*
testxdb gui header
*/
protected: VDKStatusbar* statusbar;
protected: VDKNotebook* notebook;
protected: VDKBox* notebook0_page0;
protected: VDKFrame* frame1;
protected: VDKBox* VBox15;
protected: VDKBox* hbox17;
protected: VDKTable* table2;
protected: VDKBox* vbox30;
protected: VDKLabel* label4;
protected: VDKBox* vbox31;
protected: VDKXEntry* firstname;
protected: VDKBox* vbox32;
protected: VDKLabel* label5;
protected: VDKBox* vbox33;
protected: VDKXEntry* lastname;
protected: VDKBox* vbox34;
protected: VDKLabel* label6;
protected: VDKBox* vbox35;
protected: VDKXEntry* birthdate;
protected: VDKBox* vbox36;
protected: VDKLabel* label7;
protected: VDKBox* vbox37;
protected: VDKXEntry* sex;
protected: VDKBox* vbox38;
protected: VDKBox* vbox39;
protected: VDKXCheckButton* ofage;
protected: VDKXMemo* memo;
protected: VDKBox* hbox16;
protected: VDKCustomButton* nextButton;
protected: VDKCustomButton* prevButton;
protected: VDKCustomButton* lastButton;
protected: VDKCustomButton* firstButton;
protected: VDKCustomButton* delButton;
protected: VDKCustomButton* undelButton;
protected: VDKCustomButton* showdelButton;
protected: VDKCustomButton* updateButton;
protected: VDKCustomButton* addButton;
protected: VDKCustomButton* orderButton;
protected: VDKCustomButton* quitButton;
protected: VDKBox* notebook_page1;
protected: VDKXCustomList* fieldList;
public:
DECLARE_SIGNAL_MAP(TestxdbForm);
bool OnfieldListRealize(VDKObject* sender);
bool OnquitButtonClick(VDKObject* sender);
bool OnmemoRealize(VDKObject* sender);
bool OnnextButtonClick(VDKObject* sender);
bool OnlastButtonClick(VDKObject* sender);
bool OnshowdelButtonClick(VDKObject* sender);
bool OnupdateButtonClick(VDKObject* sender);
bool OnundelButtonClick(VDKObject* sender);
bool OndelButtonClick(VDKObject* sender);
bool OnaddButtonClick(VDKObject* sender);
bool OnorderButtonClick(VDKObject* sender);
bool OnfieldListSelectRow(VDKObject* sender);
/*
declaring signal and events
dynamics tables
*/
DECLARE_SIGNAL_LIST(TestxdbForm);
DECLARE_EVENT_LIST(TestxdbForm);
// do not remove this mark: #!#
// end of file:testxdb_gui.h

==> vdkxdb2_2.0.1.orig.tar.gz: vdkxdb-2.0.1/testxdb/testxdb_gui.h <==
/*
testxdb gui header
*/
protected: VDKStatusbar* statusbar;
protected: VDKNotebook* notebook;
protected: VDKBox* notebook0_page0;
protected: VDKFrame* frame1;
protected: VDKBox* VBox15;
protected: VDKBox* hbox17;
protected: VDKTable* table2;
protected: VDKBox* vbox30;
protected: VDKLabel* label4;
protected: VDKBox* vbox31;
protected: VDKXEntry* firstname;
protected: VDKBox* vbox32;
protected: VDKLabel* label5;
protected: VDKBox* vbox33;
protected: VDKXEntry* lastname;
protected: VDKBox* vbox34;
protected: VDKLabel* label6;
protected: VDKBox* vbox35;
protected: VDKXEntry* birthdate;
protected: VDKBox* vbox36;
protected: VDKLabel* label7;
protected: VDKBox* vbox37;
protected: VDKXEntry* sex;
protected: VDKBox* vbox38;
protected: VDKBox* vbox39;
protected: VDKXCheckButton* ofage;
protected: VDKXMemo* memo;
protected: VDKBox* hbox16;
protected: VDKCustomButton* nextButton;
protected: VDKCustomButton* prevButton;
protected: VDKCustomButton* lastButton;
protected: VDKCustomButton* firstButton;
protected: VDKCustomButton* delButton;
protected: VDKCustomButton* undelButton;
protected: VDKBox* hbox21;
protected: VDKCustomButton* showdelButton;
protected: VDKCustomButton* updateButton;
protected: VDKCustomButton* addButton;
protected: VDKCustomButton* orderButton;
protected: VDKCustomButton* quitButton;
protected: VDKBox* notebook_page1;
protected: VDKXCustomList* fieldList;
public:
DECLARE_SIGNAL_MAP(TestxdbForm);
bool OnfieldListRealize(VDKObject* sender);
bool OnquitButtonClick(VDKObject* sender);
bool OnmemoRealize(VDKObject* sender);
bool OnnextButtonClick(VDKObject* sender);
bool OnlastButtonClick(VDKObject* sender);
bool OnshowdelButtonClick(VDKObject* sender);
bool OnupdateButtonClick(VDKObject* sender);
bool OnundelButtonClick(VDKObject* sender);
bool OndelButtonClick(VDKObject* sender);
bool OnaddButtonClick(VDKObject* sender);
bool OnorderButtonClick(VDKObject* sender);
bool OnfieldListSelectRow(VDKObject* sender);
/*
declaring signal and events
dynamics tables
*/
DECLARE_SIGNAL_LIST(TestxdbForm);
DECLARE_EVENT_LIST(TestxdbForm);
// declares two static used to initialize
// form display type and initial position
static GtkWindowType TestxdbForm::DisplayType;
static GtkWindowPosition TestxdbForm::InitialPosition;
// do not remove this mark: #!#

// end of file:testxdb_gui.h
